@@ -1,9 +1,9 @@
 import { useLocalStorage } from 'react-use';
 
+import { t } from '@grafana/i18n';
 import { DataQuery } from '@grafana/schema';
 import { Badge } from '@grafana/ui';
 import { QueryOperationAction } from 'app/core/components/QueryOperationRow/QueryOperationAction';
-import { t } from 'app/core/internationalization';
 import { useQueryLibraryContext } from 'app/features/explore/QueryLibrary/QueryLibraryContext';
 
 import { QUERY_LIBRARY_LOCAL_STORAGE_KEYS } from './QueryLibraryDrawer';
